version 11.0
#delimit ;
set more off;
log using "C:\matt\publications\jop2\jop\final_submission\replication\alexseev.log", replace;

*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      alexseev.do                                     *;
*       Date:           3/21/2012                                       *;
*       Author:         DJM/MG                                          *;
*       Purpose:        Alexseev replication for JOP paper              *;
*       Input File:     alexseev.dta 	                                *;
*       Output File:    alexseev.log                                    *;
*       Data Output:    None	                                        *;
*       Previous file:  None                                            *;
*       Machine:        Matt's computer                                 *;
*     ****************************************************************  *;
*     ****************************************************************  *;

use "C:\matt\publications\jop2\jop\final_submission\replication\alexseev.dta", clear;


*     ****************************************************************  *;
*	  Replicate Alexseev models         						        *;
*     ****************************************************************  *;

regress e03ld slav89 nonslav8 sl89nsl8 inc9903 eduhi02 unemp02 apt9200 vsall03 brdcont, cluster(region);

regress e03ld slav89 ch8902 sl89ch89 inc9903 eduhi02 unemp02 apt9200 vsall03 brdcont, cluster(region);

regress e03ld slav89 cau8902 sl89cau8 inc9903 eduhi02 unemp02 apt9200 vsall03 brdcont, cluster(region);

regress e03ld slav89 as8902 sl89as89 inc9903 eduhi02 unemp02 apt9200 vsall03 brdcont, cluster(region);

regress e03ld slav89 nonsla_a inc9903 eduhi02 unemp02 apt9200 vsall03 brdcont, cluster(region);

*     ****************************************************************  *;
*	  Rename variables                                                  *;
*     ****************************************************************  *;

rename e03ld xenovote;
rename slav89 slavicshare;
rename nonslav8 changenonslav;
rename sl89nsl8 slavicshare_changenonslav;
sum;

*     ****************************************************************  *;
*       Main model                                                      *;
*     ****************************************************************  *;

regress xenovote slavicshare changenonslav slavicshare_changenonslav inc9903 eduhi02 unemp02 apt9200 vsall03 brdcont, cluster(region);

set obs 10000;

*     ****************************************************************  *;
*     ****************************************************************  *;
*	  Get stuff ready to produce marginal effect plots in Figure 5.     *;
*     ****************************************************************  *;
*     ****************************************************************  *;

regress xenovote slavicshare changenonslav slavicshare_changenonslav inc9903 eduhi02 unemp02 apt9200 vsall03 brdcont, cluster(region);

matrix b=e(b); 
matrix V=e(V);
 
scalar b1=b[1,1]; 
scalar b2=b[1,2];
scalar b3=b[1,3];


scalar varb1=V[1,1]; 
scalar varb2=V[2,2]; 
scalar varb3=V[3,3];

scalar covb1b3=V[1,3]; 
scalar covb2b3=V[2,3];

scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb2b3;

*     ****************************************************************  *;
*       Calculate data necessary for producing Figure 5a.               *;
*     ****************************************************************  *;

generate MVZ=((_n-200)/100);

replace  MVZ=. if _n>1501;

gen conbx=b1+b3*MVZ if _n<1501;

gen consx=sqrt(varb1+varb3*(MVZ^2)+2*covb1b3*MVZ) if _n<1501; 

gen ax=1.96*consx;
 
gen upperx=conbx+ax;
 
gen lowerx=conbx-ax;

*     ****************************************************************  *;
*       Calculate data necessary for producing Figure 5b.               *;
*     ****************************************************************  *;

generate MVX=((_n-1)/10);

replace  MVX=. if _n>990 | _n<270;

gen conbz=b2+b3*MVX if _n<990;

gen consz=sqrt(varb2+varb3*(MVX^2)+2*covb2b3*MVX) if _n<990; 

gen az=1.96*consz;
 
gen upperz=conbz+az;
 
gen lowerz=conbz-az;

*     ****************************************************************  *;
*       Construct stuff to produce the rug plot.  Need to create an     *;
*       offset position for the pipe marker, which will depend on where *;
*       the histogram sits on the y-axis.                               *;
*     ****************************************************************  *;

gen where=-0.045;

gen where2=-1.01;

gen pipe = "|";

egen tag_nonslav = tag(changenonslav);
egen tag_slavic = tag(slavicshare);

*     ****************************************************************  *;
*       Construct variable to produce y=0 line.                         *;
*     ****************************************************************  *;

gen yline=0;

*     ****************************************************************  *;
*     ****************************************************************  *;
*       Produce Figure 5a.                                              *;
*     ****************************************************************  *;
*     ****************************************************************  *;

graph twoway hist changenonslav, width(0.5) percent color(gs14) yaxis(2)
		||   scatter where changenonslav if tag_nonslav, plotr(m(b 4)) ms(none) mlabcolor(gs5) mlabel(pipe) mlabpos(6) legend(off)
	    ||   line conbx   MVZ, clpattern(solid) clwidth(medium) clcolor(black) yaxis(1)
        ||   line upperx  MVZ, clpattern(dash) clwidth(thin) clcolor(black)
        ||   line lowerx  MVZ, clpattern(dash) clwidth(thin) clcolor(black)
	    ||   line yline  MVZ,  clwidth(thin) clcolor(black) clpattern(solid) 
	    ||   ,  
             xlabel(-2 0 2 4 6 8 10 12, nogrid labsize(2))
		     ylabel(-0.05 0 .05 .1 .15 .2 .25, axis(1) nogrid labsize(2))
		     ylabel(0 2 4 6 8 10 12 14 16, axis(2) nogrid labsize(2)) 
	         yscale(noline alt)
		     yscale(noline alt axis(2))	
             xscale(noline)
             legend(off)
		     yline(0, lcolor(black) lwidth(thin)) 
             xtitle("" , size(2.5)  )
             ytitle("" , axis(2) size(2.5))
             xsca(titlegap(2))
             ysca(titlegap(2))
			 scheme(s2mono) graphregion(fcolor(white) ilcolor(white) lcolor(white));

*     ****************************************************************  *;
*     ****************************************************************  *;
*       Produce Figure 5b.                                              *;
*     ****************************************************************  *;
*     ****************************************************************  *;

graph twoway hist slavicshare, width(3) percent color(gs14) yaxis(2)
		||   scatter where2 slavicshare if tag_slavic, plotr(m(b 4)) ms(none) mlabcolor(gs5) mlabel(pipe) mlabpos(6) legend(off)
	    ||   line conbz   MVX, clpattern(solid) clwidth(medium) clcolor(blue) clcolor(black) yaxis(1)
        ||   line upperz  MVX, clpattern(dash) clwidth(thin) clcolor(black) 
        ||   line lowerz  MVX, clpattern(dash) clwidth(thin) clcolor(black) 
        ||   line yline  MVX if MVX>90 & MVX<100,  clwidth(thin) clcolor(black) clpattern(solid) 
	    ||   ,   
		     xlabel(30 40 50 60 70 80 90 100, nogrid labsize(2)) 
             ylabel(-1 -.75 -.5 -.25 0 .25 .5, nogrid labsize(2))
             ylabel(0 5 10 15 20 25 30, axis(2) nogrid labsize(2))
             yscale(noline alt)
		     yscale(noline alt axis(2))
             xscale(noline)
             legend(off) 
             yline(0, lcolor(black) lwidth(thin))
	  	     xtitle("" , size(2.5))
             ytitle("" , axis(2) size(2.5))
             xsca(titlegap(2))
             ysca(titlegap(2))
		     scheme(s2mono) graphregion(fcolor(white) ilcolor(white) lcolor(white));

*     ****************************************************************  *;
*       Substantive significance                                        *;
*     ****************************************************************  *;

sum xenovote slavicshare changenonslav;

scalar xenovote_range= 19.5-2.8;

display xenovote_range;

*     ****************************************************************  *;
*       Look at effect of slavic share across non-slavic share          *;
*     ****************************************************************  *;

scalar marg_slavic_low = (98.87699-27.40013)*(b1+b3*-1.934565);

display marg_slavic_low;

display marg_slavic_low/xenovote_range;

scalar marg_slavic_high = (98.87699-27.40013)*(b1+b3*12.98617);

display marg_slavic_high;

display marg_slavic_high/xenovote_range;

sum MVZ if upperx>0 & lowerx>0;

*     ****************************************************************  *;
*       Look at effect of non-slavic share across slavic share          *;
*     ****************************************************************  *;

scalar marg_nonslavic_high = (12.98617+1.934565)*(b2+b3*77.4);

display marg_nonslavic_high;

display marg_nonslavic_high/xenovote_range;

scalar marg_slavic_low = (12.98617+1.934565)*(b2+b3*27.40013);

display marg_slavic_low;

display marg_slavic_low/xenovote_range;

sum MVX if upperz<0 & lowerz<0;

*     ****************************************************************  *;
*       Number of Russian regions in region of significance             *;
*     ****************************************************************  *;

sum region if  slavicshare<77.4;

log close;

